# BigFlow

## Documentation

1. [What is BigFlow?](#what-is-bigflow)
1. [Getting started](#getting-started)
1. [Help me](#help-me)
1. [CLI](./docs/cli.md)
    1. run
    1. build
    1. deploy
    1. start-project
1. [Configuration](./docs/configuration.md)
1. Build
1. Deployment
    1. Cloud Composer
    1. Kubernetes
    1. Vault
1. [Workflow & Job](./docs/workflow-and-job.md)
1. Starter
1. Utils
    1. BigQuery
    1. Apache Beam
    1. Dataproc
    1. Job monitoring
1. Roadmap

## What is BigFlow?
TODO

## Getting started
TODO

## Help me
TODO